<?php

return [
    'Names' => [
        'aa' => 'ಅಫಾರ್',
        'ab' => 'ಅಬ್ಖಾಜಿಯನ್',
        'ace' => 'ಅಛಿನೀಸ್',
        'ach' => 'ಅಕೋಲಿ',
        'ada' => 'ಅಡಂಗ್ಮೆ',
        'ady' => 'ಅಡೈಘೆ',
        'ae' => 'ಅವೆಸ್ಟನ್',
        'af' => 'ಆಫ್ರಿಕಾನ್ಸ್',
        'afh' => 'ಆಫ್ರಿಹಿಲಿ',
        'agq' => 'ಅಘೆಮ್',
        'ain' => 'ಐನು',
        'ak' => 'ಅಕಾನ್',
        'akk' => 'ಅಕ್ಕಾಡಿಯನ್',
        'ale' => 'ಅಲೆಯುಟ್',
        'alt' => 'ದಕ್ಷಿಣ ಅಲ್ಟಾಯ್',
        'am' => 'ಅಂಹರಿಕ್',
        'an' => 'ಅರಗೊನೀಸ್',
        'ang' => 'ಪ್ರಾಚೀನ ಇಂಗ್ಲೀಷ್',
        'ann' => 'ಒಬೊಲೊ',
        'anp' => 'ಆಂಗಿಕಾ',
        'ar' => 'ಅರೇಬಿಕ್',
        'arc' => 'ಅರಾಮಿಕ್',
        'arn' => 'ಮಪುಚೆ',
        'arp' => 'ಅರಪಾಹೋ',
        'ars' => 'ನ್ಯಾಜ್ಡಿ ಅರೇಬಿಕ್',
        'arw' => 'ಅರಾವಾಕ್',
        'as' => 'ಅಸ್ಸಾಮೀಸ್',
        'asa' => 'ಅಸು',
        'ast' => 'ಆಸ್ಟುರಿಯನ್',
        'atj' => 'ಅತಿಕಮೆಕ್',
        'av' => 'ಅವರಿಕ್',
        'awa' => 'ಅವಧಿ',
        'ay' => 'ಅಯ್ಮಾರಾ',
        'az' => 'ಅಜೆರ್ಬೈಜಾನಿ',
        'ba' => 'ಬಶ್ಕಿರ್',
        'bal' => 'ಬಲೂಚಿ',
        'ban' => 'ಬಲಿನೀಸ್',
        'bas' => 'ಬಸಾ',
        'be' => 'ಬೆಲರೂಸಿಯನ್',
        'bej' => 'ಬೇಜಾ',
        'bem' => 'ಬೆಂಬಾ',
        'bez' => 'ಬೆನ',
        'bg' => 'ಬಲ್ಗೇರಿಯನ್',
        'bgn' => 'ಪಶ್ಚಿಮ ಬಲೊಚಿ',
        'bho' => 'ಭೋಜಪುರಿ',
        'bi' => 'ಬಿಸ್ಲಾಮಾ',
        'bik' => 'ಬಿಕೊಲ್',
        'bin' => 'ಬಿನಿ',
        'bla' => 'ಸಿಕ್ಸಿಕಾ',
        'bm' => 'ಬಂಬಾರಾ',
        'bn' => 'ಬಾಂಗ್ಲಾ',
        'bo' => 'ಟಿಬೇಟಿಯನ್',
        'br' => 'ಬ್ರೆಟನ್',
        'bra' => 'ಬ್ರಜ್',
        'brx' => 'ಬೋಡೊ',
        'bs' => 'ಬೋಸ್ನಿಯನ್',
        'bua' => 'ಬುರಿಯಟ್',
        'bug' => 'ಬುಗಿನೀಸ್',
        'byn' => 'ಬ್ಲಿನ್',
        'ca' => 'ಕೆಟಲಾನ್',
        'cad' => 'ಕ್ಯಾಡ್ಡೋ',
        'car' => 'ಕಾರಿಬ್',
        'cay' => 'ಕಯುಗಾ',
        'cch' => 'ಅಟ್ಸಮ್',
        'ccp' => 'ಚಕ್ಮಾ',
        'ce' => 'ಚಚೆನ್',
        'ceb' => 'ಸೆಬುವಾನೊ',
        'cgg' => 'ಚಿಗಾ',
        'ch' => 'ಕಮೊರೊ',
        'chb' => 'ಚಿಬ್ಚಾ',
        'chg' => 'ಚಗಟಾಯ್',
        'chk' => 'ಚೂಕಿಸೆ',
        'chm' => 'ಮಾರಿ',
        'chn' => 'ಚಿನೂಕ್ ಜಾರ್ಗೋನ್',
        'cho' => 'ಚೋಕ್ಟಾವ್',
        'chp' => 'ಚಿಪೆವ್ಯಾನ್',
        'chr' => 'ಚೆರೋಕಿ',
        'chy' => 'ಚೀಯೆನ್ನೇ',
        'ckb' => 'ಮಧ್ಯ ಕುರ್ದಿಶ್',
        'clc' => 'ಚಿಲ್ಕೋಟಿನ್',
        'co' => 'ಕೋರ್ಸಿಕನ್',
        'cop' => 'ಕೊಪ್ಟಿಕ್',
        'cr' => 'ಕ್ರೀ',
        'crg' => 'ಮಿಚಿಫ್',
        'crh' => 'ಕ್ರಿಮೀಯನ್ ಟರ್ಕಿಷ್',
        'crj' => 'ದಕ್ಷಿಣ ಪೂರ್ವ ಕ್ರೀ',
        'crk' => 'ಪ್ಲೇನ್ಸ್ ಕ್ರೀ',
        'crl' => 'ಉತ್ತರ ಪೂರ್ವ ಕ್ರೀ',
        'crm' => 'ಮೂಸ್ ಕ್ರೀ',
        'crr' => 'ಕೆರೊಲಿನಾ ಅಲ್ಗೊಂಕ್ವಿಯನ್',
        'crs' => 'ಸೆಸೆಲ್ವಾ ಕ್ರಯೋಲ್ ಫ್ರೆಂಚ್',
        'cs' => 'ಜೆಕ್',
        'csb' => 'ಕಶುಬಿಯನ್',
        'csw' => 'ಸ್ವಾಂಪಿ ಕ್ರೀ',
        'cu' => 'ಚರ್ಚ್ ಸ್ಲಾವಿಕ್',
        'cv' => 'ಚುವಾಶ್',
        'cy' => 'ವೆಲ್ಶ್',
        'da' => 'ಡ್ಯಾನಿಶ್',
        'dak' => 'ಡಕೋಟಾ',
        'dar' => 'ದರ್ಗ್ವಾ',
        'dav' => 'ಟೈಟ',
        'de' => 'ಜರ್ಮನ್',
        'del' => 'ಡೆಲಾವೇರ್',
        'den' => 'ಸ್ಲೇವ್',
        'dgr' => 'ಡೋಗ್ರಿಬ್',
        'din' => 'ಡಿಂಕಾ',
        'dje' => 'ಜರ್ಮಾ',
        'doi' => 'ಡೋಗ್ರಿ',
        'dsb' => 'ಲೋವರ್ ಸರ್ಬಿಯನ್',
        'dua' => 'ಡುವಾಲಾ',
        'dum' => 'ಮಧ್ಯ ಡಚ್',
        'dv' => 'ದಿವೆಹಿ',
        'dyo' => 'ಜೊಲ-ಫೊನ್ಯಿ',
        'dyu' => 'ಡ್ಯೂಲಾ',
        'dz' => 'ಜೋಂಗ್‌ಖಾ',
        'dzg' => 'ಡಜಾಗ',
        'ebu' => 'ಎಂಬು',
        'ee' => 'ಈವ್',
        'efi' => 'ಎಫಿಕ್',
        'egy' => 'ಪ್ರಾಚೀನ ಈಜಿಪ್ಟಿಯನ್',
        'eka' => 'ಎಕಾಜುಕ್',
        'el' => 'ಗ್ರೀಕ್',
        'elx' => 'ಎಲಾಮೈಟ್',
        'en' => 'ಇಂಗ್ಲಿಷ್',
        'enm' => 'ಮಧ್ಯ ಇಂಗ್ಲೀಷ್',
        'eo' => 'ಎಸ್ಪೆರಾಂಟೊ',
        'es' => 'ಸ್ಪ್ಯಾನಿಷ್',
        'et' => 'ಎಸ್ಟೊನಿಯನ್',
        'eu' => 'ಬಾಸ್ಕ್',
        'ewo' => 'ಇವಾಂಡೋ',
        'fa' => 'ಪರ್ಶಿಯನ್',
        'fan' => 'ಫಾಂಗ್',
        'fat' => 'ಫಾಂಟಿ',
        'ff' => 'ಫುಲಾ',
        'fi' => 'ಫಿನ್ನಿಶ್',
        'fil' => 'ಫಿಲಿಪಿನೊ',
        'fj' => 'ಫಿಜಿಯನ್',
        'fo' => 'ಫರೋಸಿ',
        'fon' => 'ಫೋನ್',
        'fr' => 'ಫ್ರೆಂಚ್',
        'frc' => 'ಕಾಜುನ್ ಫ್ರೆಂಚ್',
        'frm' => 'ಮಧ್ಯ ಫ್ರೆಂಚ್',
        'fro' => 'ಪ್ರಾಚೀನ ಫ್ರೆಂಚ್',
        'frr' => 'ಉತ್ತರ ಫ್ರಿಸಿಯನ್',
        'frs' => 'ಪೂರ್ವ ಫ್ರಿಸಿಯನ್',
        'fur' => 'ಫ್ರಿಯುಲಿಯನ್',
        'fy' => 'ಪಶ್ಚಿಮ ಫ್ರಿಸಿಯನ್',
        'ga' => 'ಐರಿಷ್',
        'gaa' => 'ಗ',
        'gag' => 'ಗಗೌಜ್',
        'gan' => 'ಗಾನ್ ಚೀನೀಸ್',
        'gay' => 'ಗಾಯೋ',
        'gba' => 'ಗ್ಬಾಯಾ',
        'gd' => 'ಸ್ಕಾಟಿಶ್ ಗೆಲಿಕ್',
        'gez' => 'ಗೀಝ್',
        'gil' => 'ಗಿಲ್ಬರ್ಟೀಸ್',
        'gl' => 'ಗ್ಯಾಲಿಶಿಯನ್',
        'gmh' => 'ಮಧ್ಯ ಹೈ ಜರ್ಮನ್',
        'gn' => 'ಗೌರಾನಿ',
        'goh' => 'ಪ್ರಾಚೀನ ಹೈ ಜರ್ಮನ್',
        'gon' => 'ಗೊಂಡಿ',
        'gor' => 'ಗೊರೊಂಟಾಲೋ',
        'got' => 'ಗೋಥಿಕ್',
        'grb' => 'ಗ್ರೇಬೋ',
        'grc' => 'ಪ್ರಾಚೀನ ಗ್ರೀಕ್',
        'gsw' => 'ಸ್ವಿಸ್ ಜರ್ಮನ್',
        'gu' => 'ಗುಜರಾತಿ',
        'guz' => 'ಗುಸಿ',
        'gv' => 'ಮ್ಯಾಂಕ್ಸ್',
        'gwi' => 'ಗ್ವಿಚ್‌ಇನ್',
        'ha' => 'ಹೌಸಾ',
        'hai' => 'ಹೈಡಾ',
        'hak' => 'ಹಕ್',
        'haw' => 'ಹವಾಯಿಯನ್',
        'hax' => 'ದಕ್ಷಿಣ ಹೈಡಾ',
        'he' => 'ಹೀಬ್ರೂ',
        'hi' => 'ಹಿಂದಿ',
        'hil' => 'ಹಿಲಿಗೇನನ್',
        'hit' => 'ಹಿಟ್ಟಿಟೆ',
        'hmn' => 'ಮೋಂಗ್',
        'ho' => 'ಹಿರಿ ಮೊಟು',
        'hr' => 'ಕ್ರೊಯೇಶಿಯನ್',
        'hsb' => 'ಅಪ್ಪರ್ ಸರ್ಬಿಯನ್',
        'hsn' => 'ಶಯಾಂಗ್ ಚೀನೀಸೇ',
        'ht' => 'ಹೈಟಿಯನ್ ಕ್ರಿಯೋಲಿ',
        'hu' => 'ಹಂಗೇರಿಯನ್',
        'hup' => 'ಹೂಪಾ',
        'hur' => 'ಹಾಲ್ಕೊಮೆಲೆಮ್',
        'hy' => 'ಅರ್ಮೇನಿಯನ್',
        'hz' => 'ಹೆರೆರೊ',
        'ia' => 'ಇಂಟರ್‌ಲಿಂಗ್ವಾ',
        'iba' => 'ಇಬಾನ್',
        'ibb' => 'ಇಬಿಬಿಯೋ',
        'id' => 'ಇಂಡೋನೇಶಿಯನ್',
        'ie' => 'ಇಂಟರ್ಲಿಂಗ್',
        'ig' => 'ಇಗ್ಬೊ',
        'ii' => 'ಸಿಚುಅನ್ ಯಿ',
        'ik' => 'ಇನುಪಿಯಾಕ್',
        'ikt' => 'ಪಶ್ಚಿಮ ಕೆನಡಿಯನ್ ಇನುಕ್ಟಿಟುಟ್',
        'ilo' => 'ಇಲ್ಲಿಕೋ',
        'inh' => 'ಇಂಗುಷ್',
        'io' => 'ಇಡೊ',
        'is' => 'ಐಸ್‌ಲ್ಯಾಂಡಿಕ್',
        'it' => 'ಇಟಾಲಿಯನ್',
        'iu' => 'ಇನುಕ್ಟಿಟುಟ್',
        'ja' => 'ಜಾಪನೀಸ್',
        'jbo' => 'ಲೊಜ್ಬಾನ್',
        'jgo' => 'ನೊಂಬಾ',
        'jmc' => 'ಮ್ಯಕಮೆ',
        'jpr' => 'ಜೂಡಿಯೋ-ಪರ್ಶಿಯನ್',
        'jrb' => 'ಜೂಡಿಯೋ-ಅರೇಬಿಕ್',
        'jv' => 'ಜಾವಾನೀಸ್',
        'ka' => 'ಜಾರ್ಜಿಯನ್',
        'kaa' => 'ಕಾರಾ-ಕಲ್ಪಾಕ್',
        'kab' => 'ಕಬೈಲ್',
        'kac' => 'ಕಚಿನ್',
        'kaj' => 'ಜ್ಜು',
        'kam' => 'ಕಂಬಾ',
        'kaw' => 'ಕಾವಿ',
        'kbd' => 'ಕಬರ್ಡಿಯನ್',
        'kcg' => 'ಟ್ಯಾಪ್',
        'kde' => 'ಮ್ಯಾಕೊಂಡ್',
        'kea' => 'ಕಬುವೆರ್ಡಿಯನು',
        'kfo' => 'ಕೋರೋ',
        'kg' => 'ಕಾಂಗೋ',
        'kgp' => 'ಕೈಗಂಗ್',
        'kha' => 'ಖಾಸಿ',
        'kho' => 'ಖೋಟಾನೀಸ್',
        'khq' => 'ಕೊಯ್ರ ಚೀನಿ',
        'ki' => 'ಕಿಕುಯು',
        'kj' => 'ಕ್ವಾನ್‌ಯಾಮಾ',
        'kk' => 'ಕಝಕ್',
        'kkj' => 'ಕಾಕೊ',
        'kl' => 'ಕಲಾಲ್ಲಿಸುಟ್',
        'kln' => 'ಕಲೆಂಜಿನ್',
        'km' => 'ಖಮೇರ್',
        'kmb' => 'ಕಿಂಬುಂಡು',
        'kn' => 'ಕನ್ನಡ',
        'ko' => 'ಕೊರಿಯನ್',
        'koi' => 'ಕೋಮಿ-ಪರ್ಮ್ಯಕ್',
        'kok' => 'ಕೊಂಕಣಿ',
        'kos' => 'ಕೊಸರಿಯನ್',
        'kpe' => 'ಕಪೆಲ್ಲೆ',
        'kr' => 'ಕನುರಿ',
        'krc' => 'ಕರಚಯ್-ಬಲ್ಕಾರ್',
        'krl' => 'ಕರೇಲಿಯನ್',
        'kru' => 'ಕುರುಖ್',
        'ks' => 'ಕಾಶ್ಮೀರಿ',
        'ksb' => 'ಶಂಬಲ',
        'ksf' => 'ಬಫಿಯ',
        'ksh' => 'ಕಲೊಗ್ನಿಯನ್',
        'ku' => 'ಕುರ್ದಿಷ್',
        'kum' => 'ಕುಮೈಕ್',
        'kut' => 'ಕುಟೇನಾಯ್',
        'kv' => 'ಕೋಮಿ',
        'kw' => 'ಕಾರ್ನಿಷ್',
        'kwk' => 'ಕ್ವಾಕ್‌ವಾಲಾ',
        'ky' => 'ಕಿರ್ಗಿಜ್',
        'la' => 'ಲ್ಯಾಟಿನ್',
        'lad' => 'ಲ್ಯಾಡಿನೋ',
        'lag' => 'ಲಾಂಗಿ',
        'lah' => 'ಲಹಂಡಾ',
        'lam' => 'ಲಂಬಾ',
        'lb' => 'ಲಕ್ಸಂಬರ್ಗಿಷ್',
        'lez' => 'ಲೆಜ್ಘಿಯನ್',
        'lg' => 'ಗಾಂಡಾ',
        'li' => 'ಲಿಂಬರ್ಗಿಶ್',
        'lil' => 'ಲಿಲ್ಲೂವೆಟ್',
        'lkt' => 'ಲಕೊಟ',
        'ln' => 'ಲಿಂಗಾಲ',
        'lo' => 'ಲಾವೋ',
        'lol' => 'ಮೊಂಗೋ',
        'lou' => 'ಲೂಯಿಸಿಯಾನ ಕ್ರಿಯೋಲ್',
        'loz' => 'ಲೋಝಿ',
        'lrc' => 'ಉತ್ತರ ಲೂರಿ',
        'lsm' => 'ಸಾಮಿಯಾ',
        'lt' => 'ಲಿಥುವೇನಿಯನ್',
        'lu' => 'ಲೂಬಾ-ಕಟಾಂಗಾ',
        'lua' => 'ಲುಬ-ಲುಲಾ',
        'lui' => 'ಲೂಯಿಸೆನೋ',
        'lun' => 'ಲುಂಡಾ',
        'luo' => 'ಲುವೋ',
        'lus' => 'ಮಿಝೋ',
        'luy' => 'ಲುಯಿಯ',
        'lv' => 'ಲಾಟ್ವಿಯನ್',
        'mad' => 'ಮದುರೀಸ್',
        'mag' => 'ಮಗಾಹಿ',
        'mai' => 'ಮೈಥಿಲಿ',
        'mak' => 'ಮಕಾಸರ್',
        'man' => 'ಮಂಡಿಂಗೊ',
        'mas' => 'ಮಸಾಯ್',
        'mdf' => 'ಮೋಕ್ಷ',
        'mdr' => 'ಮಂದಾರ್',
        'men' => 'ಮೆಂಡೆ',
        'mer' => 'ಮೆರು',
        'mfe' => 'ಮೊರಿಸನ್',
        'mg' => 'ಮಲಗಾಸಿ',
        'mga' => 'ಮಧ್ಯ ಐರಿಷ್',
        'mgh' => 'ಮ್ಯಖುವಾ- ಮೀಟ್ಟೊ',
        'mgo' => 'ಮೆಟಾ',
        'mh' => 'ಮಾರ್ಶಲ್ಲೀಸ್',
        'mi' => 'ಮಾವೋರಿ',
        'mic' => 'ಮಿಕ್‌ಮ್ಯಾಕ್',
        'min' => 'ಮಿನಂಗ್‌ಕಬಾವು',
        'mk' => 'ಮೆಸಿಡೋನಿಯನ್',
        'ml' => 'ಮಲಯಾಳಂ',
        'mn' => 'ಮಂಗೋಲಿಯನ್',
        'mnc' => 'ಮಂಚು',
        'mni' => 'ಮಣಿಪುರಿ',
        'moe' => 'ಇನ್ನು-ಐಮುನ್',
        'moh' => 'ಮೊಹಾವ್ಕ್',
        'mos' => 'ಮೊಸ್ಸಿ',
        'mr' => 'ಮರಾಠಿ',
        'ms' => 'ಮಲಯ್',
        'mt' => 'ಮಾಲ್ಟೀಸ್',
        'mua' => 'ಮುಂಡಂಗ್',
        'mus' => 'ಕ್ರೀಕ್',
        'mwl' => 'ಮಿರಾಂಡೀಸ್',
        'mwr' => 'ಮಾರ್ವಾಡಿ',
        'my' => 'ಬರ್ಮೀಸ್',
        'myv' => 'ಎರ್ಝ್ಯಾ',
        'mzn' => 'ಮಜಂದೆರಾನಿ',
        'na' => 'ನೌರು',
        'nan' => 'ನಾನ್',
        'nap' => 'ನಿಯಾಪೊಲಿಟನ್',
        'naq' => 'ನಮ',
        'nb' => 'ನಾರ್ವೆಜಿಯನ್ ಬೊಕ್ಮಲ್',
        'nd' => 'ಉತ್ತರ ದೆಬೆಲೆ',
        'nds' => 'ಲೋ ಜರ್ಮನ್',
        'ne' => 'ನೇಪಾಳಿ',
        'new' => 'ನೇವಾರೀ',
        'ng' => 'ಡೋಂಗಾ',
        'nia' => 'ನಿಯಾಸ್',
        'niu' => 'ನಿಯುವನ್',
        'nl' => 'ಡಚ್',
        'nmg' => 'ಖ್ವಾಸಿಯೊ',
        'nn' => 'ನಾರ್ವೇಜಿಯನ್ ನೈನಾರ್ಸ್ಕ್',
        'nnh' => 'ನಿಂಬೂನ್',
        'no' => 'ನಾರ್ವೇಜಿಯನ್',
        'nog' => 'ನೊಗಾಯ್',
        'non' => 'ಪ್ರಾಚೀನ ನೋರ್ಸ್',
        'nqo' => 'ಎನ್‌ಕೋ',
        'nr' => 'ದಕ್ಷಿಣ ದೆಬೆಲೆ',
        'nso' => 'ಉತ್ತರ ಸೋಥೋ',
        'nus' => 'ನೂಯರ್',
        'nv' => 'ನವಾಜೊ',
        'nwc' => 'ಶಾಸ್ತ್ರೀಯ ನೇವಾರಿ',
        'ny' => 'ನ್ಯಾಂಜಾ',
        'nym' => 'ನ್ಯಾಮ್‌ವೆಂಜಿ',
        'nyn' => 'ನ್ಯಾನ್‌ಕೋಲೆ',
        'nyo' => 'ನ್ಯೋರೋ',
        'nzi' => 'ಜೀಮಾ',
        'oc' => 'ಒಸಿಟನ್',
        'oj' => 'ಒಜಿಬ್ವಾ',
        'ojb' => 'ವಾಯುವ್ಯ ಓಜಿಬ್ವಾ',
        'ojc' => 'ಮಧ್ಯ ಓಜಿಬ್ವಾ',
        'ojs' => 'ಓಜಿ-ಕ್ರೀ',
        'ojw' => 'ಪಶ್ಚಿಮ ಓಜಿಬ್ವಾ',
        'oka' => 'ಒಕನಾಗನ್',
        'om' => 'ಒರೊಮೊ',
        'or' => 'ಒಡಿಯ',
        'os' => 'ಒಸ್ಸೆಟಿಕ್',
        'osa' => 'ಓಸಾಜ್',
        'ota' => 'ಒಟ್ಟೋಮನ್ ತುರ್ಕಿಷ್',
        'pa' => 'ಪಂಜಾಬಿ',
        'pag' => 'ಪಂಗಾಸಿನನ್',
        'pal' => 'ಪಹ್ಲವಿ',
        'pam' => 'ಪಂಪಾಂಗಾ',
        'pap' => 'ಪಪಿಯಾಮೆಂಟೊ',
        'pau' => 'ಪಲುಆನ್',
        'pcm' => 'ನೈಜೀರಿಯನ್ ಪಿಡ್ಗಿನ್',
        'peo' => 'ಪ್ರಾಚೀನ ಪರ್ಶಿಯನ್',
        'phn' => 'ಫೀನಿಷಿಯನ್',
        'pi' => 'ಪಾಲಿ',
        'pis' => 'ಪಿಜಿನ್',
        'pl' => 'ಪೊಲಿಶ್',
        'pon' => 'ಪೋನ್‌‌ಪಿಯನ್',
        'pqm' => 'ಮ್ಯಾಲಿಸೀಟ್-ಪಸ್ಸಾಮಕ್ವಾಡ್ಡಿ',
        'prg' => 'ಪ್ರಶಿಯನ್',
        'pro' => 'ಪ್ರಾಚೀನ ಪ್ರೊವೆನ್ಶಿಯಲ್',
        'ps' => 'ಪಾಷ್ಟೋ',
        'pt' => 'ಪೋರ್ಚುಗೀಸ್',
        'qu' => 'ಕ್ವೆಚುವಾ',
        'quc' => 'ಕಿಷೆ',
        'raj' => 'ರಾಜಸ್ಥಾನಿ',
        'rap' => 'ರಾಪಾನುಯಿ',
        'rar' => 'ರಾರೋಟೊಂಗನ್',
        'rhg' => 'ರೋಹಿಂಗ್ಯಾ',
        'rm' => 'ರೊಮಾನ್ಶ್',
        'rn' => 'ರುಂಡಿ',
        'ro' => 'ರೊಮೇನಿಯನ್',
        'rof' => 'ರೊಂಬೊ',
        'rom' => 'ರೋಮಾನಿ',
        'ru' => 'ರಷ್ಯನ್',
        'rup' => 'ಅರೋಮಾನಿಯನ್',
        'rw' => 'ಕಿನ್ಯಾರ್‌ವಾಂಡಾ',
        'rwk' => 'ರುವ',
        'sa' => 'ಸಂಸ್ಕೃತ',
        'sad' => 'ಸಂಡಾವೇ',
        'sah' => 'ಸಖಾ',
        'sam' => 'ಸಮರಿಟನ್ ಅರಾಮಿಕ್',
        'saq' => 'ಸಂಬುರು',
        'sas' => 'ಸಸಾಕ್',
        'sat' => 'ಸಂತಾಲಿ',
        'sba' => 'ನಂಬೇ',
        'sbp' => 'ಸಂಗು',
        'sc' => 'ಸರ್ಡೀನಿಯನ್',
        'scn' => 'ಸಿಸಿಲಿಯನ್',
        'sco' => 'ಸ್ಕೋಟ್ಸ್',
        'sd' => 'ಸಿಂಧಿ',
        'sdh' => 'ದಕ್ಷಿಣ ಕುರ್ದಿಶ್',
        'se' => 'ಉತ್ತರ ಸಾಮಿ',
        'seh' => 'ಸೆನ',
        'sel' => 'ಸೆಲ್ಕಪ್',
        'ses' => 'ಕೊಯ್ರಬೊರೊ ಸೆನ್ನಿ',
        'sg' => 'ಸಾಂಗೋ',
        'sga' => 'ಪ್ರಾಚೀನ ಐರಿಷ್',
        'sh' => 'ಸರ್ಬೋ-ಕ್ರೊಯೇಶಿಯನ್',
        'shi' => 'ಟಷೆಲ್‍ಹಿಟ್',
        'shn' => 'ಶಾನ್',
        'si' => 'ಸಿಂಹಳ',
        'sid' => 'ಸಿಡಾಮೋ',
        'sk' => 'ಸ್ಲೋವಾಕ್',
        'sl' => 'ಸ್ಲೋವೇನಿಯನ್',
        'slh' => 'ದಕ್ಷಿಣ ಲುಶೂಟ್‌ಸೀಡ್',
        'sm' => 'ಸಮೋವನ್',
        'sma' => 'ದಕ್ಷಿಣ ಸಾಮಿ',
        'smj' => 'ಲೂಲ್ ಸಾಮಿ',
        'smn' => 'ಇನಾರಿ ಸಮೀ',
        'sms' => 'ಸ್ಕೋಟ್ ಸಾಮಿ',
        'sn' => 'ಶೋನಾ',
        'snk' => 'ಸೋನಿಂಕೆ',
        'so' => 'ಸೊಮಾಲಿ',
        'sog' => 'ಸೋಗ್ಡಿಯನ್',
        'sq' => 'ಅಲ್ಬೇನಿಯನ್',
        'sr' => 'ಸೆರ್ಬಿಯನ್',
        'srn' => 'ಸ್ರಾನನ್ ಟೋಂಗೋ',
        'srr' => 'ಸೇರೇರ್',
        'ss' => 'ಸ್ವಾತಿ',
        'ssy' => 'ಸಹೊ',
        'st' => 'ದಕ್ಷಿಣ ಸೋಥೋ',
        'str' => 'ಸ್ಟ್ರೇಟ್ಸ್ ಸೆಲಿಶ್',
        'su' => 'ಸುಂಡಾನೀಸ್',
        'suk' => 'ಸುಕುಮಾ',
        'sus' => 'ಸುಸು',
        'sux' => 'ಸುಮೇರಿಯನ್',
        'sv' => 'ಸ್ವೀಡಿಷ್',
        'sw' => 'ಸ್ವಹಿಲಿ',
        'swb' => 'ಕೊಮೊರಿಯನ್',
        'syc' => 'ಶಾಸ್ತ್ರೀಯ ಸಿರಿಯಕ್',
        'syr' => 'ಸಿರಿಯಾಕ್',
        'ta' => 'ತಮಿಳು',
        'tce' => 'ದಕ್ಷಿಣ ಟಚ್‌ವನ್',
        'te' => 'ತೆಲುಗು',
        'tem' => 'ಟಿಮ್ನೆ',
        'teo' => 'ಟೆಸೊ',
        'ter' => 'ಟೆರೆನೋ',
        'tet' => 'ಟೇಟಮ್',
        'tg' => 'ತಾಜಿಕ್',
        'tgx' => 'ಟಾಗಿಶ್',
        'th' => 'ಥಾಯ್',
        'tht' => 'ಟಾಹ್ಲ್ಟನ್',
        'ti' => 'ಟಿಗ್ರಿನ್ಯಾ',
        'tig' => 'ಟೈಗ್ರೆ',
        'tiv' => 'ಟಿವ್',
        'tk' => 'ಟರ್ಕ್‌ಮೆನ್',
        'tkl' => 'ಟೊಕೆಲಾವ್',
        'tl' => 'ಟ್ಯಾಗಲೋಗ್',
        'tlh' => 'ಕ್ಲಿಂಗನ್',
        'tli' => 'ಟ್ಲಿಂಗಿಟ್',
        'tmh' => 'ಟಮಾಷೆಕ್',
        'tn' => 'ಸ್ವಾನಾ',
        'to' => 'ಟೋಂಗನ್',
        'tog' => 'ನ್ಯಾಸಾ ಟೋಂಗಾ',
        'tok' => 'ಟೋಕಿ ಪೋನಾ',
        'tpi' => 'ಟೋಕ್ ಪಿಸಿನ್',
        'tr' => 'ಟರ್ಕಿಶ್',
        'trv' => 'ಟರೊಕೊ',
        'ts' => 'ಸೋಂಗಾ',
        'tsi' => 'ಸಿಂಶಿಯನ್',
        'tt' => 'ಟಾಟರ್',
        'ttm' => 'ಉತ್ತರ ಟಚ್‌ವನ್',
        'tum' => 'ತುಂಬುಕಾ',
        'tvl' => 'ಟುವಾಲು',
        'tw' => 'ಟ್ವಿ',
        'twq' => 'ಟಸವಕ್',
        'ty' => 'ಟಹೀಟಿಯನ್',
        'tyv' => 'ಟುವಿನಿಯನ್',
        'tzm' => 'ಮಧ್ಯ ಅಟ್ಲಾಸ್ ಟಮಜೈಟ್',
        'udm' => 'ಉಡ್‌ಮುರ್ಟ್',
        'ug' => 'ಉಯಿಘರ್',
        'uga' => 'ಉಗಾರಿಟಿಕ್',
        'uk' => 'ಉಕ್ರೇನಿಯನ್',
        'umb' => 'ಉಂಬುಂಡು',
        'ur' => 'ಉರ್ದು',
        'uz' => 'ಉಜ್ಬೇಕ್',
        'vai' => 'ವಾಯಿ',
        've' => 'ವೆಂಡಾ',
        'vi' => 'ವಿಯೆಟ್ನಾಮೀಸ್',
        'vo' => 'ವೋಲಾಪುಕ್',
        'vot' => 'ವೋಟಿಕ್',
        'vun' => 'ವುಂಜೊ',
        'wa' => 'ವಾಲೂನ್',
        'wae' => 'ವಾಲ್ಸರ್',
        'wal' => 'ವಲಾಯ್ತಾ',
        'war' => 'ವರಾಯ್',
        'was' => 'ವಾಷೋ',
        'wbp' => 'ವಾರ್ಲ್‌ಪಿರಿ',
        'wo' => 'ವೋಲೋಫ್',
        'wuu' => 'ವು ಚೈನೀಸ್',
        'xal' => 'ಕಲ್ಮೈಕ್',
        'xh' => 'ಕ್ಸೋಸ',
        'xog' => 'ಸೊಗ',
        'yao' => 'ಯಾವೊ',
        'yap' => 'ಯಪೀಸೆ',
        'yav' => 'ಯಾಂಗ್ಬೆನ್',
        'ybb' => 'ಯೆಂಬಾ',
        'yi' => 'ಯಿಡ್ಡಿಶ್',
        'yo' => 'ಯೊರುಬಾ',
        'yrl' => 'ನಿಂಗಾಟು',
        'yue' => 'ಕ್ಯಾಂಟನೀಸ್',
        'za' => 'ಝೂವಾಂಗ್',
        'zap' => 'ಝೋಪೊಟೆಕ್',
        'zbl' => 'ಬ್ಲಿಸ್ಸಿಂಬಲ್ಸ್',
        'zen' => 'ಝೆನಾಗಾ',
        'zgh' => 'ಸ್ಟ್ಯಾಂಡರ್ಡ್ ಮೊರೊಕ್ಕನ್ ಟಮಜೈಟ್',
        'zh' => 'ಚೈನೀಸ್',
        'zu' => 'ಜುಲು',
        'zun' => 'ಝೂನಿ',
        'zza' => 'ಜಾಝಾ',
    ],
    'LocalizedNames' => [
        'ar_001' => 'ಆಧುನಿಕ ಪ್ರಮಾಣಿತ ಅರೇಬಿಕ್',
        'de_AT' => 'ಆಸ್ಟ್ರಿಯನ್ ಜರ್ಮನ್',
        'de_CH' => 'ಸ್ವಿಸ್ ಹೈ ಜರ್ಮನ್',
        'en_AU' => 'ಆಸ್ಟ್ರೇಲಿಯನ್ ಇಂಗ್ಲಿಷ್',
        'en_CA' => 'ಕೆನೆಡಿಯನ್ ಇಂಗ್ಲಿಷ್',
        'en_GB' => 'ಬ್ರಿಟಿಷ್ ಇಂಗ್ಲಿಷ್',
        'en_US' => 'ಅಮೆರಿಕನ್ ಇಂಗ್ಲಿಷ್',
        'es_419' => 'ಲ್ಯಾಟಿನ್ ಅಮೇರಿಕನ್ ಸ್ಪ್ಯಾನಿಷ್',
        'es_ES' => 'ಯುರೋಪಿಯನ್ ಸ್ಪ್ಯಾನಿಷ್',
        'es_MX' => 'ಮೆಕ್ಸಿಕನ್ ಸ್ಪ್ಯಾನಿಷ್',
        'fa_AF' => 'ದರಿ',
        'fr_CA' => 'ಕೆನೆಡಿಯನ್ ಫ್ರೆಂಚ್',
        'fr_CH' => 'ಸ್ವಿಸ್ ಫ್ರೆಂಚ್',
        'nds_NL' => 'ಲೋ ಸ್ಯಾಕ್ಸನ್',
        'nl_BE' => 'ಫ್ಲೆಮಿಷ್',
        'pt_BR' => 'ಬ್ರೆಜಿಲಿಯನ್ ಪೋರ್ಚುಗೀಸ್',
        'pt_PT' => 'ಯೂರೋಪಿಯನ್ ಪೋರ್ಚುಗೀಸ್',
        'ro_MD' => 'ಮಾಲ್ಡೇವಿಯನ್',
        'sw_CD' => 'ಕಾಂಗೊ ಸ್ವಹಿಲಿ',
        'zh_Hans' => 'ಸರಳೀಕೃತ ಚೈನೀಸ್',
        'zh_Hant' => 'ಸಾಂಪ್ರದಾಯಿಕ ಚೈನೀಸ್',
    ],
];
